@@ -221,7 +221,7 @@
 
 "rinvgamma" <-
   function(n, shape, scale = 1) {
-    return(1 / rgamma(n, shape, scale))
+    return(1 / rgamma(n, shape, scale=scale))
   }
 
 ##
